import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { DownloadService } from '../service/download.service';
import {
  CDTO_download,
  CVO_download,
  FVO_download,
  QDTO_download,
  QVO_download,
  UDTO_download,
  UVAO_download,
} from '../interface/download.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['下载记录表'])
@Controller('/download')
export class DownloadController extends BaseController {
  @Inject()
  service: DownloadService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_download })
  async create(@Body() data: CDTO_download) {
    const dbData = await this.service.create(data);
    const result = new CVO_download(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_download })
  async query(
    @Query() filter: QDTO_download,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    if (this.ctx.user) filter.user = this.ctx.user._id;
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_download(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_download })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_download(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_download })
  async update(@Param('id') id: string, @Body() body: UDTO_download) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
